==> igniteui-react-charts-16.4.1.tgz: package/ES5/LineSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { HorizontalAnchoredCategorySeries } from "./HorizontalAnchoredCategorySeries";
import { IUnknownValuePlotting_$type } from "igniteui-react-core/ES5/IUnknownValuePlotting";
import { CategoryLineRasterizer } from "./CategoryLineRasterizer";
import { UnknownValuePlotting_$type } from "igniteui-react-core/ES5/UnknownValuePlotting";
import { DependencyProperty } from "igniteui-react-core/ES5/DependencyProperty";
import { Type, typeCast, runOn, enumGetBox, markType } from "igniteui-react-core/ES5/type";
import { Path } from "igniteui-react-core/ES5/Path";
import { ScalerParams } from "./ScalerParams";
import { PropertyMetadata } from "igniteui-react-core/ES5/PropertyMetadata";
import { AnchoredCategorySeriesView } from "./AnchoredCategorySeriesView";
import { ISortingAxis_$type } from "./ISortingAxis";
import { Color } from "igniteui-react-core/ES5/Color";
var LineSeries = /** @class */ (function (_super) {
    tslib_1.__extends(LineSeries, _super);
    function LineSeries() {
        var _this = _super.call(this) || this;
        _this.p7 = null;
        _this.p7 = new CategoryLineRasterizer();
        _this.ab = LineSeries.$;
        _this.pr = 0;
        return _this;
    }
    LineSeries.prototype.bf = function () {
        return new LineSeriesView(this);
    };
    LineSeries.prototype.il = function (a) {
        _super.prototype.il.call(this, a);
        this.p8 = a;
    };
    LineSeries.prototype.get_ck = function () {
        return true;
    };
    Object.defineProperty(LineSeries.prototype, "ck", {
        get: function () {
            return this.get_ck();
        },
        enumerable: true,
        configurable: true
    });
    LineSeries.prototype.preferredCategoryMode = function (a) {
        return this.pr;
    };
    LineSeries.prototype.ho = function (a, b) {
        _super.prototype.ho.call(this, a, b);
        var c = b;
        c.c5();
    };
    LineSeries.prototype.oe = function (a, b) {
        _super.prototype.oe.call(this, a, b);
        var c = b.cl.d;
        var d = typeCast(LineSeriesView.$, b);
        var e = a.f;
        var f = this.getEffectiveViewport1(b);
        this.m5.x(this, this.nq(), this.po, runOn(this, this.mr), this.ny(b), this.nz(b));
        var g = false;
        var h = this.m5.c;
        if (h != null) {
            g = true;
        }
        if (g) {
            var i = new ScalerParams(0, b.bq, b.bp, this.po.b8, f);
            this.oa(e, -1, this.valueColumn.count, this.po, i, b.n);
        }
        var j = d.db;
        var k = d.dc;
        var l = d.da;
        this.m5.ae(j, true, false, true, false);
        this.m5.ae(k, true, false, true, false);
        this.m5.ae(l, false, true, false, false);
        l._opacity = 0.75 * this.m5.i;
        if (b.cp(a)) {
            d.c6(e.count, e, true, this.unknownValuePlotting, this.om(e, e.count - 1, b.bp, b.bq), c, this.eq);
            b.cs(a);
        }
    };
    LineSeries.prototype.ir = function (a, b, c, d) {
        _super.prototype.ir.call(this, a, b, c, d);
        switch (b) {
            case LineSeries.$$p[0]:
                this.m2.m = this.unknownValuePlotting == 0;
                this.i4(false);
                this.ib();
                break;
        }
    };
    Object.defineProperty(LineSeries.prototype, "useHighMarkerFidelity", {
        get: function () {
            return this.nt;
        },
        enumerable: true,
        configurable: true
    });
    LineSeries.$t = markType(LineSeries, 'LineSeries', HorizontalAnchoredCategorySeries.$, [IUnknownValuePlotting_$type]);
    return LineSeries;
}(HorizontalAnchoredCategorySeries));
export { LineSeries };
Type.dep(DependencyProperty, PropertyMetadata, LineSeries, 'raisePropertyChanged', ['UnknownValuePlotting::qa', [UnknownValuePlotting_$type, enumGetBox(UnknownValuePlotting_$type, 1)]]);
var LineSeriesView = /** @class */ (function (_super) {
    tslib_1.__extends(LineSeriesView, _super);
    function LineSeriesView(a) {
        var _this = _super.call(this, a) || this;
        _this.c4 = null;
        _this.de = new Path();
        _this.dd = new Path();
        _this.df = new Path();
        _this.c9 = new Path();
        _this.c8 = new Path();
        _this.c7 = new Path();
        _this.c4 = a;
        return _this;
    }
    Object.defineProperty(LineSeriesView.prototype, "db", {
        get: function () {
            return this.de;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(LineSeriesView.prototype, "dc", {
        get: function () {
            return this.df;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(LineSeriesView.prototype, "da", {
        get: function () {
            return this.dd;
        },
        enumerable: true,
        configurable: true
    });
    LineSeriesView.prototype.c5 = function () {
        this.dd.aj = null;
        this.de.aj = null;
        this.df.aj = null;
        this.an();
    };
    LineSeriesView.prototype.c6 = function (a, b, c, d, e, f, g) {
        this.c4.p7.a = typeCast(ISortingAxis_$type, this.cn.fetchXAxis()) !== null ? true : false;
        this.c4.p7.m(this.de, this.dd, this.df, a, b, c, d, e, f, g);
        this.an();
    };
    LineSeriesView.prototype.a8 = function () {
        _super.prototype.a8.call(this);
    };
    LineSeriesView.prototype.a9 = function () {
        _super.prototype.a9.call(this);
        this.c8.aj = this.de.aj;
        this.c9.aj = this.df.aj;
        this.c7.aj = this.dd.aj;
        var a = this.bk();
        this.c8._stroke = a;
        this.c8.ac = this.e.eu + 3;
        this.c9._stroke = a;
        this.c9.ac = this.e.eu + 3;
        this.c7._fill = a;
        this.c7._opacity = 1;
    };
    LineSeriesView.prototype.a3 = function (a, b) {
        _super.prototype.a3.call(this, a, b);
        if (a.d) {
            if (b) {
                a.s(this.c7);
                a.s(this.c8);
                a.s(this.c9);
            }
            else {
                a.s(this.dd);
                a.s(this.de);
                a.s(this.df);
            }
        }
    };
    LineSeriesView.prototype.ai = function (a) {
        _super.prototype.ai.call(this, a);
        this.e.a2.exportPathData(a, this.de, "lowerShape", ["Lower", "Main"]);
        this.e.a2.exportPathData(a, this.df, "upperShape", ["Upper"]);
        this.e.a2.exportPathData(a, this.dd, "translucentShape", ["Translucent"]);
    };
    LineSeriesView.prototype.ac = function () {
        var a = new Color();
        a.colorString = "rgba(95,95,95,0.5)";
        this.e.k1 = a;
        this.e.er = 3;
        this.e.es = 1;
        this.e.et = 4;
        this.e.ds = false;
    };
    LineSeriesView.$t = markType(LineSeriesView, 'LineSeriesView', AnchoredCategorySeriesView.$);
    return LineSeriesView;
}(AnchoredCategorySeriesView));
export { LineSeriesView };
/*<BeginStatics Name="Infragistics.Controls.Charts.LineSeries" />*/
/*<EndStatics Name="Infragistics.Controls.Charts.LineSeries" />*/

==> igniteui-react-charts-16.6.4.tgz: package/ES5/LineSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { HorizontalAnchoredCategorySeries } from "./HorizontalAnchoredCategorySeries";
import { IUnknownValuePlotting_$type } from "igniteui-react-core/ES5/IUnknownValuePlotting";
import { CategoryLineRasterizer } from "./CategoryLineRasterizer";
import { UnknownValuePlotting_$type } from "igniteui-react-core/ES5/UnknownValuePlotting";
import { DependencyProperty } from "igniteui-react-core/ES5/DependencyProperty";
import { Type, typeCast, runOn, enumGetBox, markType } from "igniteui-react-core/ES5/type";
import { Path } from "igniteui-react-core/ES5/Path";
import { ScalerParams } from "./ScalerParams";
import { PropertyMetadata } from "igniteui-react-core/ES5/PropertyMetadata";
import { AnchoredCategorySeriesView } from "./AnchoredCategorySeriesView";
import { ISortingAxis_$type } from "./ISortingAxis";
import { Color } from "igniteui-react-core/ES5/Color";
var LineSeries = /** @class */ (function (_super) {
    tslib_1.__extends(LineSeries, _super);
    function LineSeries() {
        var _this = _super.call(this) || this;
        _this.p8 = null;
        _this.p8 = new CategoryLineRasterizer();
        _this.ab = LineSeries.$;
        _this.ps = 0;
        return _this;
    }
    LineSeries.prototype.bf = function () {
        return new LineSeriesView(this);
    };
    LineSeries.prototype.il = function (a) {
        _super.prototype.il.call(this, a);
        this.p9 = a;
    };
    LineSeries.prototype.get_ck = function () {
        return true;
    };
    LineSeries.prototype.preferredCategoryMode = function (a) {
        return this.ps;
    };
    LineSeries.prototype.ho = function (a, b) {
        _super.prototype.ho.call(this, a, b);
        var c = b;
        c.c7();
    };
    LineSeries.prototype.of = function (a, b) {
        _super.prototype.of.call(this, a, b);
        var c = b.cn.d;
        var d = typeCast(LineSeriesView.$, b);
        var e = a.f;
        var f = this.getEffectiveViewport1(b);
        this.m5.x(this, this.nq(), this.pp, runOn(this, this.mr), this.ny(b), this.nz(b));
        var g = false;
        var h = this.m5.c;
        if (h != null) {
            g = true;
        }
        if (g) {
            var i = new ScalerParams(0, b.bs, b.br, this.pp.b8, f);
            this.ob(e, -1, this.valueColumn.count, this.pp, i, b.n);
        }
        var j = d.dd;
        var k = d.de;
        var l = d.dc;
        this.m5.ae(j, true, false, true, false);
        this.m5.ae(k, true, false, true, false);
        this.m5.ae(l, false, true, false, false);
        l._opacity = 0.75 * this.m5.i;
        if (b.cr(a)) {
            d.c8(e.count, e, true, this.unknownValuePlotting, this.on(e, e.count - 1, b.br, b.bs), c, this.eq);
            b.cu(a);
        }
    };
    LineSeries.prototype.ir = function (a, b, c, d) {
        _super.prototype.ir.call(this, a, b, c, d);
        switch (b) {
            case LineSeries.$$p[0]:
                this.m2.m = this.unknownValuePlotting == 0;
                this.i4(false);
                this.ib();
                break;
        }
    };
    Object.defineProperty(LineSeries.prototype, "useHighMarkerFidelity", {
        get: function () {
            return this.nt;
        },
        enumerable: true,
        configurable: true
    });
    LineSeries.$t = markType(LineSeries, 'LineSeries', HorizontalAnchoredCategorySeries.$, [IUnknownValuePlotting_$type]);
    return LineSeries;
}(HorizontalAnchoredCategorySeries));
export { LineSeries };
Type.dep(DependencyProperty, PropertyMetadata, LineSeries, 'raisePropertyChanged', ['UnknownValuePlotting::qb', [UnknownValuePlotting_$type, enumGetBox(UnknownValuePlotting_$type, 1)]]);
var LineSeriesView = /** @class */ (function (_super) {
    tslib_1.__extends(LineSeriesView, _super);
    function LineSeriesView(a) {
        var _this = _super.call(this, a) || this;
        _this.c6 = null;
        _this.dg = new Path();
        _this.df = new Path();
        _this.dh = new Path();
        _this.db = new Path();
        _this.da = new Path();
        _this.c9 = new Path();
        _this.c6 = a;
        return _this;
    }
    Object.defineProperty(LineSeriesView.prototype, "dd", {
        get: function () {
            return this.dg;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(LineSeriesView.prototype, "de", {
        get: function () {
            return this.dh;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(LineSeriesView.prototype, "dc", {
        get: function () {
            return this.df;
        },
        enumerable: true,
        configurable: true
    });
    LineSeriesView.prototype.c7 = function () {
        this.df.aj = null;
        this.dg.aj = null;
        this.dh.aj = null;
        this.an();
    };
    LineSeriesView.prototype.c8 = function (a, b, c, d, e, f, g) {
        this.c6.p8.a = typeCast(ISortingAxis_$type, this.cp.fetchXAxis()) !== null ? true : false;
        this.c6.p8.m(this.dg, this.df, this.dh, a, b, c, d, e, f, g);
        this.an();
    };
    LineSeriesView.prototype.a8 = function () {
        _super.prototype.a8.call(this);
    };
    LineSeriesView.prototype.a9 = function () {
        _super.prototype.a9.call(this);
        this.da.aj = this.dg.aj;
        this.db.aj = this.dh.aj;
        this.c9.aj = this.df.aj;
        var a = this.bl();
        this.da._stroke = a;
        this.da.ac = this.e.eu + 3;
        this.db._stroke = a;
        this.db.ac = this.e.eu + 3;
        this.c9._fill = a;
        this.c9._opacity = 1;
    };
    LineSeriesView.prototype.a3 = function (a, b) {
        _super.prototype.a3.call(this, a, b);
        if (a.d) {
            if (b) {
                a.s(this.c9);
                a.s(this.da);
                a.s(this.db);
            }
            else {
                a.s(this.df);
                a.s(this.dg);
                a.s(this.dh);
            }
        }
    };
    LineSeriesView.prototype.ai = function (a) {
        _super.prototype.ai.call(this, a);
        this.e.a2.exportPathData(a, this.dg, "lowerShape", ["Lower", "Main"]);
        this.e.a2.exportPathData(a, this.dh, "upperShape", ["Upper"]);
        this.e.a2.exportPathData(a, this.df, "translucentShape", ["Translucent"]);
    };
    LineSeriesView.prototype.ac = function () {
        var a = new Color();
        a.colorString = "rgba(95,95,95,0.5)";
        this.e.k1 = a;
        this.e.er = 3;
        this.e.es = 1;
        this.e.et = 4;
        this.e.ds = false;
    };
    LineSeriesView.$t = markType(LineSeriesView, 'LineSeriesView', AnchoredCategorySeriesView.$);
    return LineSeriesView;
}(AnchoredCategorySeriesView));
export { LineSeriesView };
